@@ -58,7 +58,8 @@ modavg.shrink <-
 
     
     ##determine if unmarked
-    unmarked.class <- c("unmarkedFitOccu", "unmarkedFitColExt", "unmarkedFitOccuRN", "unmarkedFitPCount", "unmarkedFitPCO")
+    unmarked.class <- c("unmarkedFitOccu", "unmarkedFitColExt", "unmarkedFitOccuRN", "unmarkedFitPCount", "unmarkedFitPCO",
+                        "unmarkedFitDS", "unmarkedFitGDS")
     if(any(sapply(unmarked.class, FUN = function(i) identical(i, check.class)))) {
       mod.avg.shrink <- modavg.shrink.unmarked(cand.set = cand.set, parm = parm, modnames = modnames, c.hat = c.hat, conf.level = conf.level,
                                         second.ord = second.ord, nobs = nobs, uncond.se = uncond.se, parm.type = parm.type)
